@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2019 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the Qt Gui module
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2019 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #ifndef QRHI_H
 #define QRHI_H
@@ -74,7 +38,7 @@ class QRhiSampler;
 class QRhiCommandBuffer;
 class QRhiResourceUpdateBatch;
 class QRhiResourceUpdateBatchPrivate;
-class QRhiProfiler;
+class QRhiSwapChain;
 
 class Q_GUI_EXPORT QRhiDepthStencilClearValue
 {
@@ -296,6 +260,9 @@ class Q_GUI_EXPORT QRhiShaderStage
 public:
     enum Type {
         Vertex,
+        TessellationControl,
+        TessellationEvaluation,
+        Geometry,
         Fragment,
         Compute
     };
@@ -336,6 +303,8 @@ public:
     enum Type {
         UniformBuffer,
         SampledTexture,
+        Texture,
+        Sampler,
         ImageLoad,
         ImageStore,
         ImageLoadStore,
@@ -346,8 +315,11 @@ public:
 
     enum StageFlag {
         VertexStage = 1 << 0,
-        FragmentStage = 1 << 1,
-        ComputeStage = 1 << 2
+        TessellationControlStage = 1 << 1,
+        TessellationEvaluationStage = 1 << 2,
+        GeometryStage = 1 << 3,
+        FragmentStage = 1 << 4,
+        ComputeStage = 1 << 5
     };
     Q_DECLARE_FLAGS(StageFlags, StageFlag)
 
@@ -367,6 +339,10 @@ public:
     };
     static QRhiShaderResourceBinding sampledTextures(int binding, StageFlags stage, int count, const TextureAndSampler *texSamplers);
 
+    static QRhiShaderResourceBinding texture(int binding, StageFlags stage, QRhiTexture *tex);
+    static QRhiShaderResourceBinding textures(int binding, StageFlags stage, int count, QRhiTexture **tex);
+    static QRhiShaderResourceBinding sampler(int binding, StageFlags stage, QRhiSampler *sampler);
+
     static QRhiShaderResourceBinding imageLoad(int binding, StageFlags stage, QRhiTexture *tex, int level);
     static QRhiShaderResourceBinding imageStore(int binding, StageFlags stage, QRhiTexture *tex, int level);
     static QRhiShaderResourceBinding imageLoadStore(int binding, StageFlags stage, QRhiTexture *tex, int level);
@@ -390,7 +366,7 @@ public:
             bool hasDynamicOffset;
         };
         static const int MAX_TEX_SAMPLER_ARRAY_SIZE = 16;
-        struct SampledTextureData {
+        struct TextureAndOrSamplerData {
             int count;
             TextureAndSampler texSamplers[MAX_TEX_SAMPLER_ARRAY_SIZE];
         };
@@ -405,11 +381,18 @@ public:
         };
         union {
             UniformBufferData ubuf;
-            SampledTextureData stex;
+            TextureAndOrSamplerData stex;
             StorageImageData simage;
             StorageBufferData sbuf;
         } u;
 
+        int arraySize() const
+        {
+            return type == QRhiShaderResourceBinding::SampledTexture || type == QRhiShaderResourceBinding::Texture
+                    ? u.stex.count
+                    : 1;
+        }
+
         template<typename Output>
         Output serialize(Output dst) const
         {
@@ -417,7 +400,7 @@ public:
             *dst++ = quint32(binding);
             *dst++ = quint32(stage);
             *dst++ = quint32(type);
-            *dst++ = quint32(type == QRhiShaderResourceBinding::SampledTexture ? u.stex.count : 1);
+            *dst++ = quint32(arraySize());
             return dst;
         }
     };
@@ -679,7 +662,7 @@ public:
         Sampler,
         RenderBuffer,
         RenderPassDescriptor,
-        RenderTarget,
+        SwapChainRenderTarget,
         TextureRenderTarget,
         ShaderResourceBindings,
         GraphicsPipeline,
@@ -772,7 +755,9 @@ public:
         UsedWithLoadStore = 1 << 7,
         UsedAsCompressedAtlas = 1 << 8,
         ExternalOES = 1 << 9,
-        ThreeDimensional = 1 << 10
+        ThreeDimensional = 1 << 10,
+        TextureRectangleGL = 1 << 11,
+        TextureArray = 1 << 12
     };
     Q_DECLARE_FLAGS(Flags, Flag)
 
@@ -792,6 +777,8 @@ public:
         R16F,
         R32F,
 
+        RGB10A2,
+
         D16,
         D24,
         D24S8,
@@ -841,6 +828,17 @@ public:
     int depth() const { return m_depth; }
     void setDepth(int depth) { m_depth = depth; }
 
+    int arraySize() const { return m_arraySize; }
+    void setArraySize(int arraySize) { m_arraySize = arraySize; }
+
+    int arrayRangeStart() const { return m_arrayRangeStart; }
+    int arrayRangeLength() const { return m_arrayRangeLength; }
+    void setArrayRange(int startIndex, int count)
+    {
+        m_arrayRangeStart = startIndex;
+        m_arrayRangeLength = count;
+    }
+
     Flags flags() const { return m_flags; }
     void setFlags(Flags f) { m_flags = f; }
 
@@ -854,12 +852,15 @@ public:
 
 protected:
     QRhiTexture(QRhiImplementation *rhi, Format format_, const QSize &pixelSize_, int depth_,
-                int sampleCount_, Flags flags_);
+                int arraySize_, int sampleCount_, Flags flags_);
     Format m_format;
     QSize m_pixelSize;
     int m_depth;
+    int m_arraySize;
     int m_sampleCount;
     Flags m_flags;
+    int m_arrayRangeStart = -1;
+    int m_arrayRangeLength = -1;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QRhiTexture::Flags)
@@ -986,6 +987,8 @@ public:
 
     virtual QRhiRenderPassDescriptor *newCompatibleRenderPassDescriptor() const = 0;
 
+    virtual QVector<quint32> serializedFormat() const = 0;
+
 protected:
     QRhiRenderPassDescriptor(QRhiImplementation *rhi);
 };
@@ -993,8 +996,6 @@ protected:
 class Q_GUI_EXPORT QRhiRenderTarget : public QRhiResource
 {
 public:
-    QRhiResource::Type resourceType() const override;
-
     virtual QSize pixelSize() const = 0;
     virtual float devicePixelRatio() const = 0;
     virtual int sampleCount() const = 0;
@@ -1007,6 +1008,17 @@ protected:
     QRhiRenderPassDescriptor *m_renderPassDesc = nullptr;
 };
 
+class Q_GUI_EXPORT QRhiSwapChainRenderTarget : public QRhiRenderTarget
+{
+public:
+    QRhiResource::Type resourceType() const override;
+    QRhiSwapChain *swapChain() const { return m_swapchain; }
+
+protected:
+    QRhiSwapChainRenderTarget(QRhiImplementation *rhi, QRhiSwapChain *swapchain_);
+    QRhiSwapChain *m_swapchain;
+};
+
 class Q_GUI_EXPORT QRhiTextureRenderTarget : public QRhiRenderTarget
 {
 public:
@@ -1104,7 +1116,8 @@ public:
         TriangleFan,
         Lines,
         LineStrip,
-        Points
+        Points,
+        Patches
     };
 
     enum CullMode {
@@ -1196,6 +1209,11 @@ public:
         CompareOp compareOp = Always;
     };
 
+    enum PolygonMode {
+        Fill,
+        Line
+    };
+
     QRhiResource::Type resourceType() const override;
 
     Flags flags() const { return m_flags; }
@@ -1275,6 +1293,12 @@ public:
     QRhiRenderPassDescriptor *renderPassDescriptor() const { return m_renderPassDesc; }
     void setRenderPassDescriptor(QRhiRenderPassDescriptor *desc) { m_renderPassDesc = desc; }
 
+    int patchControlPointCount() const { return m_patchControlPointCount; }
+    void setPatchControlPointCount(int count) { m_patchControlPointCount = count; }
+
+    PolygonMode polygonMode() const {return m_polygonMode; }
+    void setPolygonMode(PolygonMode mode) {m_polygonMode = mode; }
+
     virtual bool create() = 0;
 
 protected:
@@ -1296,6 +1320,8 @@ protected:
     float m_lineWidth = 1.0f;
     int m_depthBias = 0;
     float m_slopeScaledDepthBias = 0.0f;
+    int m_patchControlPointCount = 3;
+    PolygonMode m_polygonMode = Fill;
     QVarLengthArray<QRhiShaderStage, 4> m_shaderStages;
     QRhiVertexInputLayout m_vertexInputLayout;
     QRhiShaderResourceBindings *m_shaderResourceBindings = nullptr;
@@ -1306,6 +1332,31 @@ Q_DECLARE_OPERATORS_FOR_FLAGS(QRhiGraphicsPipeline::Flags)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QRhiGraphicsPipeline::ColorMask)
 Q_DECLARE_TYPEINFO(QRhiGraphicsPipeline::TargetBlend, Q_RELOCATABLE_TYPE);
 
+struct QRhiSwapChainHdrInfo
+{
+    bool isHardCodedDefaults;
+    enum LimitsType {
+        LuminanceInNits,
+        ColorComponentValue
+    };
+    LimitsType limitsType;
+    union {
+        struct {
+            float minLuminance;
+            float maxLuminance;
+        } luminanceInNits;
+        struct {
+            float maxColorComponentValue;
+        } colorComponentValue;
+    } limits;
+};
+
+Q_DECLARE_TYPEINFO(QRhiSwapChainHdrInfo, Q_RELOCATABLE_TYPE);
+
+#ifndef QT_NO_DEBUG_STREAM
+Q_GUI_EXPORT QDebug operator<<(QDebug, const QRhiSwapChainHdrInfo &);
+#endif
+
 class Q_GUI_EXPORT QRhiSwapChain : public QRhiResource
 {
 public:
@@ -1319,6 +1370,12 @@ public:
     };
     Q_DECLARE_FLAGS(Flags, Flag)
 
+    enum Format {
+        SDR,
+        HDRExtendedSrgbLinear,
+        HDR10
+    };
+
     QRhiResource::Type resourceType() const override;
 
     QWindow *window() const { return m_window; }
@@ -1327,6 +1384,9 @@ public:
     Flags flags() const { return m_flags; }
     void setFlags(Flags f) { m_flags = f; }
 
+    Format format() const { return m_format; }
+    void setFormat(Format f) { m_format = f; }
+
     QRhiRenderBuffer *depthStencil() const { return m_depthStencil; }
     void setDepthStencil(QRhiRenderBuffer *ds) { m_depthStencil = ds; }
 
@@ -1341,13 +1401,16 @@ public:
     virtual QRhiCommandBuffer *currentFrameCommandBuffer() = 0;
     virtual QRhiRenderTarget *currentFrameRenderTarget() = 0;
     virtual QSize surfacePixelSize() = 0;
+    virtual bool isFormatSupported(Format f) = 0;
     virtual QRhiRenderPassDescriptor *newCompatibleRenderPassDescriptor() = 0;
     virtual bool createOrResize() = 0;
+    virtual QRhiSwapChainHdrInfo hdrInfo();
 
 protected:
     QRhiSwapChain(QRhiImplementation *rhi);
     QWindow *m_window = nullptr;
     Flags m_flags;
+    Format m_format = SDR;
     QRhiRenderBuffer *m_depthStencil = nullptr;
     int m_sampleCount = 1;
     QRhiRenderPassDescriptor *m_renderPassDesc = nullptr;
@@ -1520,6 +1583,20 @@ Q_DECLARE_TYPEINFO(QRhiDriverInfo, Q_RELOCATABLE_TYPE);
 Q_GUI_EXPORT QDebug operator<<(QDebug, const QRhiDriverInfo &);
 #endif
 
+struct Q_GUI_EXPORT QRhiMemAllocStats
+{
+    quint32 blockCount = 0;
+    quint32 allocCount = 0;
+    quint64 usedBytes = 0;
+    quint64 unusedBytes = 0;
+};
+
+Q_DECLARE_TYPEINFO(QRhiMemAllocStats, Q_RELOCATABLE_TYPE);
+
+#ifndef QT_NO_DEBUG_STREAM
+Q_GUI_EXPORT QDebug operator<<(QDebug, const QRhiMemAllocStats &);
+#endif
+
 struct Q_GUI_EXPORT QRhiInitParams
 {
 };
@@ -1580,7 +1657,12 @@ public:
         ImageDataStride,
         RenderBufferImport,
         ThreeDimensionalTextures,
-        RenderTo3DTextureSlice
+        RenderTo3DTextureSlice,
+        TextureArrays,
+        Tessellation,
+        GeometryShader,
+        TextureArrayRange,
+        NonFillPolygonMode
     };
 
     enum BeginFrameFlag {
@@ -1602,7 +1684,11 @@ public:
         MaxThreadsPerThreadGroup,
         MaxThreadGroupX,
         MaxThreadGroupY,
-        MaxThreadGroupZ
+        MaxThreadGroupZ,
+        TextureArraySizeMax,
+        MaxUniformBufferRange,
+        MaxVertexInputs,
+        MaxVertexOutputs
     };
 
     ~QRhi();
@@ -1611,6 +1697,7 @@ public:
                         QRhiInitParams *params,
                         Flags flags = {},
                         QRhiNativeHandles *importDevice = nullptr);
+    static bool probe(Implementation impl, QRhiInitParams *params);
 
     Implementation backend() const;
     const char *backendName() const;
@@ -1621,6 +1708,9 @@ public:
     void addCleanupCallback(const CleanupCallback &callback);
     void runCleanup();
 
+    using GpuFrameTimeCallback = std::function<void(float t)>;
+    void addGpuFrameTimeCallback(const GpuFrameTimeCallback &callback);
+
     QRhiGraphicsPipeline *newGraphicsPipeline();
     QRhiComputePipeline *newComputePipeline();
     QRhiShaderResourceBindings *newShaderResourceBindings();
@@ -1645,6 +1735,12 @@ public:
                             int sampleCount = 1,
                             QRhiTexture::Flags flags = {});
 
+    QRhiTexture *newTextureArray(QRhiTexture::Format format,
+                                 int arraySize,
+                                 const QSize &pixelSize,
+                                 int sampleCount = 1,
+                                 QRhiTexture::Flags flags = {});
+
     QRhiSampler *newSampler(QRhiSampler::Filter magFilter,
                             QRhiSampler::Filter minFilter,
                             QRhiSampler::Filter mipmapMode,
@@ -1689,8 +1785,6 @@ public:
     const QRhiNativeHandles *nativeHandles();
     bool makeThreadLocalNativeContextCurrent();
 
-    QRhiProfiler *profiler();
-
     static const int MAX_MIP_LEVELS = 16; // a width and/or height of 65536 should be enough for everyone
 
     void releaseCachedResources();
@@ -1700,6 +1794,8 @@ public:
     QByteArray pipelineCacheData();
     void setPipelineCacheData(const QByteArray &data);
 
+    QRhiMemAllocStats graphicsMemoryAllocationStatistics() const;
+
 protected:
     QRhi();
 
