@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 
 #include <QTest>
@@ -748,7 +723,7 @@ void tst_QGraphicsLinearLayout::orientation()
     // important to resize to preferredsize when orientation is switched
     widget->resize(widget->effectiveSizeHint(Qt::PreferredSize));
     qApp->processEvents();
-    for (i = 0; i < positions.count(); ++i) {
+    for (i = 0; i < positions.size(); ++i) {
         QGraphicsWidget *item = static_cast<QGraphicsWidget*>(layout.itemAt(i));
         if (initialOrientation == Qt::Horizontal)
             QCOMPARE(item->pos().y(), positions.at(i));
@@ -1146,7 +1121,7 @@ void tst_QGraphicsLinearLayout::setStretchFactor()
 
 
     int i;
-    for (i = 0; i < stretches.count(); ++i) {
+    for (i = 0; i < stretches.size(); ++i) {
         QGraphicsWidget *item = new RectWidget(widget);
         item->setMinimumSize(5,5);
         item->setPreferredSize(10,5);
@@ -1164,7 +1139,7 @@ void tst_QGraphicsLinearLayout::setStretchFactor()
     qreal firstStretch = -1;
     qreal firstExtent = -1.;
     qreal sumExtent = 0;
-    for (i = 0; i < stretches.count(); ++i) {
+    for (i = 0; i < stretches.size(); ++i) {
         QGraphicsWidget *item = static_cast<QGraphicsWidget*>(layout.itemAt(i));
         qreal extent = item->size().width();
         qreal stretch = (qreal)stretches.at(i);
@@ -1322,7 +1297,7 @@ void tst_QGraphicsLinearLayout::defaultStretchFactors()
         QSizeF itemSize = layout->itemAt(i)->geometry().size();
         if (orientation == Qt::Vertical)
             itemSize.transpose();
-        if (i < expectedSizes.count())
+        if (i < expectedSizes.size())
             QCOMPARE(itemSize.width(), qreal(expectedSizes.at(i)));
     }
 
